==> pentobi_8.2.orig.tar.xz: pentobi-8.2/src/libpentobi_base/Book.h <==
//-----------------------------------------------------------------------------
/** @file libpentobi_base/Book.h
    @author Markus Enzenberger
    @copyright GNU General Public License version 3 or later */
//-----------------------------------------------------------------------------

#ifndef LIBPENTOBI_BASE_BOOK_H
#define LIBPENTOBI_BASE_BOOK_H

#include <iosfwd>
#include "Board.h"
#include "Game.h"
#include "Tree.h"
#include "libboardgame_base/PointTransform.h"
#include "libboardgame_util/RandomGenerator.h"

namespace libpentobi_base {

using libboardgame_util::RandomGenerator;

//-----------------------------------------------------------------------------

/** Opening book.
    Opening books are stored as trees in SGF files. Thay contain move
    annotation properties according to the SGF standard. The book will select
    randomly among the child nodes that have the move annotation good move
    or very good move (TE[1] or TE[2]). */
class Book
{
public:
    Book(Variant variant);

    void load(istream& in);

    Move genmove(const Board& bd, Color c);

    const Tree& get_tree() const;

private:
    typedef libboardgame_base::PointTransform<Point> PointTransform;

    Tree m_tree;

    RandomGenerator m_random;

    bool genmove(const Board& bd, Color c, Move& mv,
                 const PointTransform& transform,
                 const PointTransform& inv_transform);

    Move get_transformed(const Board& bd, Move mv,
                         const PointTransform& transform) const;

    const Node* select_child(const Board& bd, Color c, const Tree& tree,
                             const Node& node,
                             const PointTransform& inv_transform);
};

inline const Tree& Book::get_tree() const
{
    return m_tree;
}

//-----------------------------------------------------------------------------

} // namespace libpentobi_base

#endif // LIBPENTOBI_BASE_BOOK_H

==> pentobi_9.0.orig.tar.xz: pentobi-9.0/src/libpentobi_base/Book.h <==
//-----------------------------------------------------------------------------
/** @file libpentobi_base/Book.h
    @author Markus Enzenberger
    @copyright GNU General Public License version 3 or later */
//-----------------------------------------------------------------------------

#ifndef LIBPENTOBI_BASE_BOOK_H
#define LIBPENTOBI_BASE_BOOK_H

#include <iosfwd>
#include "Board.h"
#include "Game.h"
#include "PentobiTree.h"
#include "libboardgame_base/PointTransform.h"
#include "libboardgame_util/RandomGenerator.h"

namespace libpentobi_base {

using libboardgame_util::RandomGenerator;

//-----------------------------------------------------------------------------

/** Opening book.
    Opening books are stored as trees in SGF files. Thay contain move
    annotation properties according to the SGF standard. The book will select
    randomly among the child nodes that have the move annotation good move
    or very good move (TE[1] or TE[2]). */
class Book
{
public:
    Book(Variant variant);

    void load(istream& in);

    Move genmove(const Board& bd, Color c);

    const PentobiTree& get_tree() const;

private:
    typedef libboardgame_base::PointTransform<Point> PointTransform;

    PentobiTree m_tree;

    RandomGenerator m_random;

    bool genmove(const Board& bd, Color c, Move& mv,
                 const PointTransform& transform,
                 const PointTransform& inv_transform);

    Move get_transformed(const Board& bd, Move mv,
                         const PointTransform& transform) const;

    const SgfNode* select_child(const Board& bd, Color c,
                                const PentobiTree& tree, const SgfNode& node,
                                const PointTransform& inv_transform);
};

inline const PentobiTree& Book::get_tree() const
{
    return m_tree;
}

//-----------------------------------------------------------------------------

} // namespace libpentobi_base

#endif // LIBPENTOBI_BASE_BOOK_H
